<?php
declare(strict_types = 1);

return [
    'authorName' => null,
    'authorUrl' => null,
    'cms' => null,
    'code' => [
        'html' => '<img src="https://cdn2.thecatapi.com/images/cjd.jpg" />',
        'width' => null,
        'height' => null,
        'ratio' => null
    ],
    'description' => null,
    'favicon' => 'https://cdn2.thecatapi.com/favicon.ico',
    'feeds' => [],
    'icon' => null,
    'image' => 'https://cdn2.thecatapi.com/images/cjd.jpg',
    'keywords' => [],
    'language' => null,
    'languages' => [],
    'license' => null,
    'providerName' => 'Thecatapi',
    'providerUrl' => 'https://cdn2.thecatapi.com',
    'publishedTime' => null,
    'redirect' => null,
    'title' => null,
    'url' => 'https://cdn2.thecatapi.com/images/cjd.jpg',
    'linkedData' => [],
    'oEmbed' => [],
    'allLinkedData' => []
];
